# Lightnimage

## Installation

pip install lightnimage

## Changelog

### 0.0.0.7 - 06.11.2018

initial version

### 0.0.0.8 - 06.11.2018

- Wrote functions to calculate (in calculate.py):
    - the 2d average of a matrix
    - all combinations of elements from two lists
    - Sequences passing a certain threshold
- Added an engine, which calculates the areas of maximum signal